\name{plotSticks}
\alias{plotSticks}

\title{Draw a stick-plot diagram}

\description{Draw a stick-plot diagram}

\usage{plotSticks(x, y, u, v, yscale=1, add=FALSE, length=1/20,
           mgp=getOption("oceMgp"),
           mar=c(mgp[1]+1,mgp[1]+1,1,1+par("cex")),
           \dots)}
\arguments{
\item{x}{x coordinates of stick origins.}
\item{y}{y coordinates of stick origins.  If not supplied, 0 will be used; if
    length is less than that of x, the first number is repeated and the rest
    are ignored.}
\item{u}{x component of stick length.}
\item{v}{y component of stick length.}
\item{yscale}{scale from u and v to y (see \dQuote{Details}).}
\item{add}{boolean, set \code{TRUE} to add to an existing plot.}
\item{length}{value to be provided to \code{\link{arrows}}; here, we set
  a default that is smaller than normally used, because these plots tend
  to be crowded in oceanographic applications.}
\item{mgp}{3-element numerical vector to use for \code{par(mgp)}, and
  also for \code{par(mar)}, computed from this.  The default is
  tighter than the R default, in order to use more space for the data
  and less for the axes.}
\item{mar}{value to be used with \code{\link{par}("mar")}.}
\item{\dots}{graphical parameters passed down to \code{\link{arrows}}.
  It is common, for example, to use smaller arrow heads than
  \code{\link{arrows}} uses; see \dQuote{Examples}.}
}

\details{The arrows are drawn with directions on the graph that match
  the directions indicated by the \code{u} and \code{v} components. The
  arrow size is set relative to the units of the \code{y} axis,
  according to the value of \code{yscale}, which has the unit of
  \code{v} divided by the unit of \code{y}.

  The interpretation of diagrams produced by \code{plotSticks} can
  be difficult, owing to overlap in the arrows.  For this reason, it It
  is often a good idea to smooth \code{u} and \code{v} before using this
  function.
}

\examples{
library(oce)

# Flow from a point source
n <- 16
x <- rep(0, n)
y <- rep(0, n)
theta <- seq(0, 2*pi, length.out=n)
u <- sin(theta)
v <- cos(theta)
plotSticks(x, y, u, v, xlim=c(-2, 2), ylim=c(-2, 2))
rm(n, x, y, theta, u, v)

# Oceanographic example
if (require(ocedata)) {
    data(met)
    t <- ISOdatetime(met[["Year"]], met[["Month"]], met[["Day"]], 0, 0, 0, tz="UTC")
    u <- met[["u"]]
    v <- met[["v"]]
    temperature <- met[["temperature"]]
    oce.plot.ts(t, temperature, type='p', ylim=c(-5, 30))
    plotSticks(t, 5, u, v, yscale=2, add=TRUE)
}
}

\author{Dan Kelley}

\keyword{hplot}
